==> rest-assured-1.7.2-sources.jar: com/jayway/restassured/internal/matcher/xml/XmlXsdMatcher.java <==
package com.jayway.restassured.internal.matcher.xml;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class XmlXsdMatcher
  extends org.hamcrest.BaseMatcher<java.lang.String>  implements
    groovy.lang.GroovyObject {
public XmlXsdMatcher
(java.lang.Object xsd) {}
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  java.lang.Object getXsd() { return null;}
public  void setXsd(java.lang.Object value) { }
public static  org.hamcrest.Matcher<java.lang.String> matchesXsd(java.lang.String xsd) { return (org.hamcrest.Matcher<java.lang.String>)null;}
public static  org.hamcrest.Matcher<java.lang.String> matchesXsd(java.io.InputStream xsd) { return (org.hamcrest.Matcher<java.lang.String>)null;}
public static  org.hamcrest.Matcher<java.lang.String> matchesXsd(java.io.Reader xsd) { return (org.hamcrest.Matcher<java.lang.String>)null;}
public static  org.hamcrest.Matcher<java.lang.String> matchesXsd(java.io.File xsd) { return (org.hamcrest.Matcher<java.lang.String>)null;}
public static  org.hamcrest.Matcher<java.lang.String> matchesXsd(java.net.URL url) { return (org.hamcrest.Matcher<java.lang.String>)null;}
@java.lang.Override() public  boolean matches(java.lang.Object item) { return false;}
@java.lang.Override() public  void describeTo(org.hamcrest.Description description) { }
}

==> rest-assured-2.2.0-sources.jar: com/jayway/restassured/internal/matcher/xml/XmlXsdMatcher.java <==
package com.jayway.restassured.internal.matcher.xml;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class XmlXsdMatcher
  extends org.hamcrest.BaseMatcher<java.lang.String>  implements
    groovy.lang.GroovyObject {
public XmlXsdMatcher
(java.lang.Object xsd) {}
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  java.lang.Object getXsd() { return null;}
public  void setXsd(java.lang.Object value) { }
public static  org.hamcrest.Matcher<java.lang.String> matchesXsd(java.lang.String xsd) { return (org.hamcrest.Matcher)null;}
public static  org.hamcrest.Matcher<java.lang.String> matchesXsd(java.io.InputStream xsd) { return (org.hamcrest.Matcher)null;}
public static  org.hamcrest.Matcher<java.lang.String> matchesXsd(java.io.Reader xsd) { return (org.hamcrest.Matcher)null;}
public static  org.hamcrest.Matcher<java.lang.String> matchesXsd(java.io.File xsd) { return (org.hamcrest.Matcher)null;}
public static  org.hamcrest.Matcher<java.lang.String> matchesXsd(java.net.URL url) { return (org.hamcrest.Matcher)null;}
@java.lang.Override() public  boolean matches(java.lang.Object item) { return false;}
@java.lang.Override() public  void describeTo(org.hamcrest.Description description) { }
}
